| brdu | R Documentation |
BrdU incorporation in fibroblast cultures measured under four dose
conditions. For each culture and dose condition, three replicate measurements
are available. The data set is provided in long format and can be used to
illustrate dependent replicate measurements in nparLD().
brdu
A data frame with 60 rows and 4 variables:
BrdU incorporation response.
Dose condition, with levels 0, 0.1, 1, and 10.
Culture identifier. This is the independent experimental unit.
Replicate identifier within each culture-dose condition.
The original variables were CultureNo, Replic, Dose, and Brdu.
In the package data set, the variables were renamed to culture,
replicate, dose, and resp for consistency with the examples.
## Not run:
data(brdu)
fit <- nparLD(
resp ~ dose,
data = brdu,
subject = "culture",
replicate = "replicate",
hypothesis = "H0p",
cell.weights = "subjects"
)
fit
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.