Learn R Programming

nparLD (version 2.3.1)

nparLD-package: nparLD: Nonparametric Longitudinal Data Analysis

Description

The nparLD package provides nonparametric methods for the analysis of longitudinal and repeated-measures data in factorial experiments. It is especially useful for settings in which response distributions may be non-normal, ordinal, skewed, heteroscedastic, or affected by ties. The procedures do not require distributional assumptions, and are applicable to a variety of data types (continuous, discrete, purely ordinal, and dichotomous). The methods are also robust with respect to outliers and for small sample sizes.

Arguments

Main function

  • nparLD() performs the nonparametric analysis.

Hypotheses

The argument hypothesis = "H0F" tests hypotheses in marginal distribution functions. The argument hypothesis = "H0p" tests hypotheses in unweighted relative marginal Mann-Whitney effects and thus addresses the nonparametric Behrens-Fisher problem in factorial longitudinal designs.

Effects

The argument effect = "weighted" estimates weighted relative marginal Mann-Whitney effects using classical ranks (mid-ranks) of the observations. The argument effect = "unweighted" estimates unweighted relative marginal Mann-Whitney effects using pseudo-ranks of the data. The weighted relative marginal effect depends on sample sizes and their allocations, whereas the unweighted relative marginal effect does not.

Contrast

The argument contrast = list() estimates and tests contrasts on the given factor levels or their interaction effects using multiple contrast tests. If the null hypothesis H0p is tested, then simultaneous confidence intervals are computed.

Replicates

Dependent replicates can be specified by the replicate argument. For relative marginal effects, the cell.weights argument determines whether subject-condition cells or individual replicate observations define the target of estimation.

Author

Maintainer: Frank Konietschke frank.konietschke@charite.de

Authors:

Other contributors:

  • Kimihiro Noguchi (Original package author) [contributor]

  • Mahbub Latif (Original package author) [contributor]

  • Karthinathan Thangavelu (Original package author) [contributor]

  • Yulia R. Gel (Original package author) [contributor]

  • Edgar Brunner [contributor]

Details

The main function is nparLD(), which implements inference for hypotheses in marginal distribution functions and in unweighted relative marginal effects. The package supports crossed factorial designs with whole-plot and sub-plot factors, missing observations, dependent replicate measurements, rank- and pseudo-rank-based estimation, confidence intervals, Wald-type and ANOVA-type statistics, multiple contrast procedures, and simultaneous confidence intervals.