panic2: Panic Disorder Study II

panic2R Documentation

Panic Disorder Study II

Description

Panic and agoraphobia scores from patients with panic disorder, with or without agoraphobia. The data illustrate a factorial longitudinal design with one whole-plot factor and one repeated-measures factor.

Usage

panic2

Format

A data frame with variables:

resp

Panic and agoraphobia score.

time

Visit or week of assessment.

group

Agoraphobia group.

subject

Patient identifier.

Examples

data(panic2)

## Not run: 
fit <- nparLD(resp ~ group * time,
              data = panic2,
              subject = "subject",
              hypothesis = "H0F", effect="unweighted")
fit

## End(Not run)

## Not run: 
fit <- nparLD(resp ~ group * time,
              data = panic2,
              subject = "subject",
              hypothesis = "H0p",
              contrast = list("group:time"),
              Factor.Information = TRUE,
              covariance=TRUE)
fit
plot(fit)
plot(fit$MCTP)

## End(Not run)


nparLD documentation built on Aug. 28, 2026, 5:06 p.m.