| plasma | R Documentation |
Plasma-renin activity measurements from a randomized study of healthy non-smokers. The data illustrate a factorial longitudinal design with one whole-plot factor and one repeated-measures factor.
plasma
A data frame with variables:
Plasma-renin activity measurement.
Measurement time.
Drug group.
Subject identifier.
data(plasma)
## Not run:
fit <- nparLD(resp ~ group * time,
data = plasma,
subject = "subject",
hypothesis = "H0F", effect="weighted")
fit
## End(Not run)
## Not run:
fit <- nparLD(resp ~ group * time,
data = plasma,
subject = "subject",
hypothesis = "H0p",
contrast = list("group", "Tukey"))
fit
plot(fit)
plot(fit$MCTP)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.