| print.nparld_covarianceinfo | R Documentation |
Displays the estimated covariance matrix of the relative effect estimator.
## S3 method for class 'nparld_covarianceinfo'
print(x, digits = 4, ...)
x |
An object of class |
digits |
Number of digits used for printing numerical results. |
... |
Further arguments. |
The printed matrix is the estimated covariance matrix used for the selected
hypothesis. It is returned when covariance = TRUE.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.