| print.nparld_factorinfo | R Documentation |
Prints factor-specific relative effects, standard errors, and confidence
limits for the main effects and interactions of an nparLD() fit.
Factor information is returned when the model is fitted with
Factor.Information = TRUE and can also be displayed graphically with
plot(fit, term = ...).
## S3 method for class 'nparld_factorinfo'
print(x, digits = 4, ...)
x |
An object of class |
digits |
Number of digits used for printing numerical results. |
... |
Further arguments. |
Factor information consists of term-specific relative effects, standard
errors, and confidence limits for main effects and interactions. These
summaries are returned when Factor.Information = TRUE and can be
visualized with plot(fit, term = ...).
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.