| print.nparld_mctp | R Documentation |
Prints the global and local results of a multiple contrast test procedure.
The local results include contrast estimates, standard errors, simultaneous
confidence limits, test statistics, adjusted p-values, and degrees of freedom.
The contrast matrix can optionally be displayed with
show.matrix = TRUE.
## S3 method for class 'nparld_mctp'
print(x, digits = 4, show.matrix = FALSE, ...)
x |
An object of class |
digits |
Number of digits used for printing numerical results. |
show.matrix |
Logical. If |
... |
Further arguments. |
The method prints the global multiple contrast test and the local contrast
results, including estimates, standard errors, simultaneous confidence
limits, test statistics, adjusted p-values, and degrees of freedom. The
contrast matrix is stored in x$Contrast.Matrix and is printed only
when show.matrix = TRUE.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.