shoulder: Shoulder Tip Pain Study

shoulderR Documentation

Shoulder Tip Pain Study

Description

Shoulder pain scores from patients after laparoscopic abdominal surgery. The study includes treatment group, gender group, and repeated pain measurements.

Usage

shoulder

Format

A data frame with variables:

resp

Shoulder pain score.

time

Measurement occasion.

group1

Treatment group.

group2

Gender group.

subject

Patient identifier.

Examples

data(shoulder)

## Not run: 
fit <- nparLD(resp ~ group1 * group2 * time,
              data = shoulder,
              subject = "subject",
              hypothesis = "H0F")
fit

## End(Not run)

## Not run: 
fit <- nparLD(resp ~ group1 * group2 * time,
              data = shoulder,
              subject = "subject",
              hypothesis = "H0p",
              contrast = list("group1:time"),
              Factor.Information=TRUE)
fit
plot(fit)
plot(fit$MCTP)

## End(Not run)


nparLD documentation built on Aug. 28, 2026, 5:06 p.m.