tree: Vitality of Treetops

treeR Documentation

Vitality of Treetops

Description

Repeated vitality scores of treetops from three experimental areas. The data illustrate an ordinal longitudinal response in several groups.

Usage

tree

Format

A data frame with variables:

resp

Vitality score.

time

Year or measurement occasion.

group

Experimental area.

subject

Tree identifier.

Examples

data(tree)

## Not run: 
fit <- nparLD(resp ~ group * time,
              data = tree,
              subject = "subject",
              hypothesis = "H0F")
fit

## End(Not run)


## Not run: 
fit <- nparLD(resp ~ group * time,
              data = tree,
              subject = "subject",
              hypothesis = "H0p",
              contrast = list("group:time"))
fit
plot(fit)
plot(fit$MCTP)

## End(Not run)


nparLD documentation built on Aug. 28, 2026, 5:06 p.m.