Learn R Programming

nparLD (version 2.3.1)

brdu: BrdU incorporation in fibroblasts

Description

BrdU incorporation in fibroblast cultures measured under four dose conditions. For each culture and dose condition, three replicate measurements are available. The data set is provided in long format and can be used to illustrate dependent replicate measurements in nparLD().

Usage

brdu

Arguments

Format

A data frame with 60 rows and 4 variables:

resp

BrdU incorporation response.

dose

Dose condition, with levels 0, 0.1, 1, and 10.

culture

Culture identifier. This is the independent experimental unit.

replicate

Replicate identifier within each culture-dose condition.

Details

The original variables were CultureNo, Replic, Dose, and Brdu. In the package data set, the variables were renamed to culture, replicate, dose, and resp for consistency with the examples.

Examples

Run this code
if (FALSE) {
data(brdu)

fit <- nparLD(
  resp ~ dose,
  data = brdu,
  subject = "culture",
  replicate = "replicate",
  hypothesis = "H0p",
  cell.weights = "subjects"
)

fit
}

Run the code above in your browser using DataLab