BrdU incorporation in fibroblast cultures measured under four dose
conditions. For each culture and dose condition, three replicate measurements
are available. The data set is provided in long format and can be used to
illustrate dependent replicate measurements in nparLD().
Usage
brdu
Arguments
Format
A data frame with 60 rows and 4 variables:
resp
BrdU incorporation response.
dose
Dose condition, with levels 0, 0.1, 1, and 10.
culture
Culture identifier. This is the independent experimental unit.
replicate
Replicate identifier within each culture-dose condition.
Details
The original variables were CultureNo, Replic, Dose, and Brdu.
In the package data set, the variables were renamed to culture,
replicate, dose, and resp for consistency with the examples.