| panic2 | R Documentation |
Panic and agoraphobia scores from patients with panic disorder, with or without agoraphobia. The data illustrate a factorial longitudinal design with one whole-plot factor and one repeated-measures factor.
panic2
A data frame with variables:
Panic and agoraphobia score.
Visit or week of assessment.
Agoraphobia group.
Patient identifier.
data(panic2)
## Not run:
fit <- nparLD(resp ~ group * time,
data = panic2,
subject = "subject",
hypothesis = "H0F", effect="unweighted")
fit
## End(Not run)
## Not run:
fit <- nparLD(resp ~ group * time,
data = panic2,
subject = "subject",
hypothesis = "H0p",
contrast = list("group:time"),
Factor.Information = TRUE,
covariance=TRUE)
fit
plot(fit)
plot(fit$MCTP)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.