Learn R Programming

nparLD (version 2.3.1)

panic2: Panic Disorder Study II

Description

Panic and agoraphobia scores from patients with panic disorder, with or without agoraphobia. The data illustrate a factorial longitudinal design with one whole-plot factor and one repeated-measures factor.

Usage

panic2

Arguments

Format

A data frame with variables:

resp

Panic and agoraphobia score.

time

Visit or week of assessment.

group

Agoraphobia group.

subject

Patient identifier.

Examples

Run this code
data(panic2)

if (FALSE) {
fit <- nparLD(resp ~ group * time,
              data = panic2,
              subject = "subject",
              hypothesis = "H0F", effect="unweighted")
fit
}

if (FALSE) {
fit <- nparLD(resp ~ group * time,
              data = panic2,
              subject = "subject",
              hypothesis = "H0p",
              contrast = list("group:time"),
              Factor.Information = TRUE,
              covariance=TRUE)
fit
plot(fit)
plot(fit$MCTP)
}

Run the code above in your browser using DataLab