Learn R Programming

nparLD (version 2.3.1)

plasma: Plasma-renin Activity Study

Description

Plasma-renin activity measurements from a randomized study of healthy non-smokers. The data illustrate a factorial longitudinal design with one whole-plot factor and one repeated-measures factor.

Usage

plasma

Arguments

Format

A data frame with variables:

resp

Plasma-renin activity measurement.

time

Measurement time.

group

Drug group.

subject

Subject identifier.

Examples

Run this code
data(plasma)

if (FALSE) {
fit <- nparLD(resp ~ group * time,
              data = plasma,
              subject = "subject",
              hypothesis = "H0F", effect="weighted")
fit
}

if (FALSE) {
fit <- nparLD(resp ~ group * time,
              data = plasma,
              subject = "subject",
              hypothesis = "H0p",
              contrast = list("group", "Tukey"))
fit
plot(fit)
plot(fit$MCTP)
}

Run the code above in your browser using DataLab