Learn R Programming

nparLD (version 2.3.1)

print.nparld_covarianceinfo: Print nparLD covariance matrix

Description

Displays the estimated covariance matrix of the relative effect estimator.

Usage

# S3 method for nparld_covarianceinfo
print(x, digits = 4, ...)

Arguments

x

An object of class "nparld_covarianceinfo".

digits

Number of digits used for printing numerical results.

...

Further arguments.

Details

The printed matrix is the estimated covariance matrix used for the selected hypothesis. It is returned when covariance = TRUE.