Displays the estimated covariance matrix of the relative effect estimator.
# S3 method for nparld_covarianceinfo
print(x, digits = 4, ...)An object of class "nparld_covarianceinfo".
Number of digits used for printing numerical results.
Further arguments.
The printed matrix is the estimated covariance matrix used for the selected
hypothesis. It is returned when covariance = TRUE.