Learn R Programming

nparLD (version 2.3.1)

print.nparld_factorinfo: Print nparLD factor information

Description

Prints factor-specific relative effects, standard errors, and confidence limits for the main effects and interactions of an nparLD() fit. Factor information is returned when the model is fitted with Factor.Information = TRUE and can also be displayed graphically with plot(fit, term = ...).

Usage

# S3 method for nparld_factorinfo
print(x, digits = 4, ...)

Arguments

x

An object of class "nparld_factorinfo".

digits

Number of digits used for printing numerical results.

...

Further arguments.

Details

Factor information consists of term-specific relative effects, standard errors, and confidence limits for main effects and interactions. These summaries are returned when Factor.Information = TRUE and can be visualized with plot(fit, term = ...).