Prints factor-specific relative effects, standard errors, and confidence
limits for the main effects and interactions of an nparLD() fit.
Factor information is returned when the model is fitted with
Factor.Information = TRUE and can also be displayed graphically with
plot(fit, term = ...).
# S3 method for nparld_factorinfo
print(x, digits = 4, ...)An object of class "nparld_factorinfo".
Number of digits used for printing numerical results.
Further arguments.
Factor information consists of term-specific relative effects, standard
errors, and confidence limits for main effects and interactions. These
summaries are returned when Factor.Information = TRUE and can be
visualized with plot(fit, term = ...).