| print.nparld_fit | R Documentation |
Prints the main results of a fitted nparLD() model, including the
detected design, hypothesis type, ranking method, estimated relative effects,
and global WTS and ATS results. Optional components such as factor-specific
information, multiple contrast results, covariance matrices, and permutation
tests are displayed when available.
## S3 method for class 'nparld_fit'
print(x, digits = 4, ...)
x |
An object of class |
digits |
Number of digits used for printed numerical results. |
... |
Further arguments. |
The print method displays the detected design, sample size information, hypothesis type, ranking method, estimated relative effects, and global WTS and ATS results. Optional components are printed when available, including factor-specific information, multiple contrast results, covariance matrices, and permutation test results.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.