Prints the main components of a summarized nparLD() fit, including
design information, hypothesis type, estimated relative effects, and global
WTS and ATS results. Optional components such as factor-specific information,
multiple contrast results, covariance matrices, and permutation tests are
displayed when available.
# S3 method for summary.nparld_fit
print(x, digits = 4, ...)An object of class "summary.nparld_fit".
Number of digits used for printing numerical results.
Further arguments.