| shoulder | R Documentation |
Shoulder pain scores from patients after laparoscopic abdominal surgery. The study includes treatment group, gender group, and repeated pain measurements.
shoulder
A data frame with variables:
Shoulder pain score.
Measurement occasion.
Treatment group.
Gender group.
Patient identifier.
data(shoulder)
## Not run:
fit <- nparLD(resp ~ group1 * group2 * time,
data = shoulder,
subject = "subject",
hypothesis = "H0F")
fit
## End(Not run)
## Not run:
fit <- nparLD(resp ~ group1 * group2 * time,
data = shoulder,
subject = "subject",
hypothesis = "H0p",
contrast = list("group1:time"),
Factor.Information=TRUE)
fit
plot(fit)
plot(fit$MCTP)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.