| summary.nparld_fit | R Documentation |
Extracts the main components of a fitted nparLD() object into a
structured summary object. The summary is useful for inspecting, printing, or
programmatically accessing the main results without working directly with all
internal components of the fitted object.
## S3 method for class 'nparld_fit'
summary(object, ...)
object |
An object of class |
... |
Further arguments passed to or from other methods. |
The summary method returns a structured list containing the main components
of the fitted object. In contrast to print(), which is mainly intended
for console display, summary() is useful for storing or extracting the
main results programmatically.
An object of class "summary.nparld_fit" containing selected
components of the fitted model.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.