| tree | R Documentation |
Repeated vitality scores of treetops from three experimental areas. The data illustrate an ordinal longitudinal response in several groups.
tree
A data frame with variables:
Vitality score.
Year or measurement occasion.
Experimental area.
Tree identifier.
data(tree)
## Not run:
fit <- nparLD(resp ~ group * time,
data = tree,
subject = "subject",
hypothesis = "H0F")
fit
## End(Not run)
## Not run:
fit <- nparLD(resp ~ group * time,
data = tree,
subject = "subject",
hypothesis = "H0p",
contrast = list("group:time"))
fit
plot(fit)
plot(fit$MCTP)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.