Learn R Programming

nparLD (version 2.3.1)

tree: Vitality of Treetops

Description

Repeated vitality scores of treetops from three experimental areas. The data illustrate an ordinal longitudinal response in several groups.

Usage

tree

Arguments

Format

A data frame with variables:

resp

Vitality score.

time

Year or measurement occasion.

group

Experimental area.

subject

Tree identifier.

Examples

Run this code
data(tree)

if (FALSE) {
fit <- nparLD(resp ~ group * time,
              data = tree,
              subject = "subject",
              hypothesis = "H0F")
fit
}


if (FALSE) {
fit <- nparLD(resp ~ group * time,
              data = tree,
              subject = "subject",
              hypothesis = "H0p",
              contrast = list("group:time"))
fit
plot(fit)
plot(fit$MCTP)
}

Run the code above in your browser using DataLab